---
title: <span class="badge builder"></span> DashboardMeta
---
# <span class="badge builder"></span> DashboardMeta

## Constructor

```python
DashboardMeta()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> dashboard.DashboardMeta
```

### <span class="badge object-method"></span> annotations_permissions

```python
def annotations_permissions(annotations_permissions: cogbuilder.Builder[dashboard.AnnotationPermission]) -> typing.Self
```

### <span class="badge object-method"></span> can_admin

```python
def can_admin(can_admin: bool) -> typing.Self
```

### <span class="badge object-method"></span> can_delete

```python
def can_delete(can_delete: bool) -> typing.Self
```

### <span class="badge object-method"></span> can_edit

```python
def can_edit(can_edit: bool) -> typing.Self
```

### <span class="badge object-method"></span> can_save

```python
def can_save(can_save: bool) -> typing.Self
```

### <span class="badge object-method"></span> can_star

```python
def can_star(can_star: bool) -> typing.Self
```

### <span class="badge object-method"></span> created

```python
def created(created: str) -> typing.Self
```

### <span class="badge object-method"></span> created_by

```python
def created_by(created_by: str) -> typing.Self
```

### <span class="badge object-method"></span> expires

```python
def expires(expires: str) -> typing.Self
```

### <span class="badge object-method"></span> folder_id

Deprecated: use FolderUID instead

```python
def folder_id(folder_id: int) -> typing.Self
```

### <span class="badge object-method"></span> folder_title

```python
def folder_title(folder_title: str) -> typing.Self
```

### <span class="badge object-method"></span> folder_uid

```python
def folder_uid(folder_uid: str) -> typing.Self
```

### <span class="badge object-method"></span> folder_url

```python
def folder_url(folder_url: str) -> typing.Self
```

### <span class="badge object-method"></span> has_acl

```python
def has_acl(has_acl: bool) -> typing.Self
```

### <span class="badge object-method"></span> is_folder

```python
def is_folder(is_folder: bool) -> typing.Self
```

### <span class="badge object-method"></span> is_snapshot

```python
def is_snapshot(is_snapshot: bool) -> typing.Self
```

### <span class="badge object-method"></span> is_starred

```python
def is_starred(is_starred: bool) -> typing.Self
```

### <span class="badge object-method"></span> provisioned

```python
def provisioned(provisioned: bool) -> typing.Self
```

### <span class="badge object-method"></span> provisioned_external_id

```python
def provisioned_external_id(provisioned_external_id: str) -> typing.Self
```

### <span class="badge object-method"></span> public_dashboard_enabled

```python
def public_dashboard_enabled(public_dashboard_enabled: bool) -> typing.Self
```

### <span class="badge object-method"></span> public_dashboard_uid

```python
def public_dashboard_uid(public_dashboard_uid: str) -> typing.Self
```

### <span class="badge object-method"></span> slug

```python
def slug(slug: str) -> typing.Self
```

### <span class="badge object-method"></span> type_val

```python
def type_val(type_val: str) -> typing.Self
```

### <span class="badge object-method"></span> updated

```python
def updated(updated: str) -> typing.Self
```

### <span class="badge object-method"></span> updated_by

```python
def updated_by(updated_by: str) -> typing.Self
```

### <span class="badge object-method"></span> url

```python
def url(url: str) -> typing.Self
```

### <span class="badge object-method"></span> version

```python
def version(version: int) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [DashboardMeta](./object-DashboardMeta.md)
